=== modified file 'NEWS'
--- NEWS	2007-03-14 05:08:55 +0000
+++ NEWS	2007-03-14 15:22:51 +0000
@@ -46,6 +46,8 @@
     * Switch the ``bzr init-repo`` default from --no-trees to --trees. 
       (Wouter van Heyst, #53483)
 
+    * Take smtp_server from user config into account.
+      (vila, #92195)
  
 bzr 0.15rc1  2007-03-07
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-03-13 18:11:45 +0000
+++ bzrlib/builtins.py	2007-03-14 10:37:18 +0000
@@ -3410,7 +3410,7 @@
             server = branch.get_config().get_user_option('smtp_server')
             if not server:
                 server = 'localhost'
-            s.connect()
+            s.connect(server)
             s.sendmail(message['From'], message['To'], message.as_string())
 
 

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2007-03-11 16:16:00 +0000
+++ bzrlib/merge_directive.py	2007-03-13 16:59:44 +0000
@@ -98,14 +98,15 @@
         patch_lines = list(line_iter)
         if len(patch_lines) == 0:
             patch = None
+            patch_type = None
         else:
             patch = ''.join(patch_lines)
-        try:
-            bundle_serializer.read_bundle(StringIO(patch))
-        except errors.NotABundle:
-            patch_type = 'diff'
-        else:
-            patch_type = 'bundle'
+            try:
+                bundle_serializer.read_bundle(StringIO(patch))
+            except errors.NotABundle:
+                patch_type = 'diff'
+            else:
+                patch_type = 'bundle'
         time, timezone = timestamp.parse_patch_date(stanza.get('timestamp'))
         kwargs = {}
         for key in ('revision_id', 'testament_sha1', 'target_branch',
@@ -114,6 +115,7 @@
                 kwargs[key] = stanza.get(key)
             except KeyError:
                 pass
+        kwargs['revision_id'] = kwargs['revision_id'].encode('utf-8')
         return MergeDirective(time=time, timezone=timezone,
                               patch_type=patch_type, patch=patch, **kwargs)
 

=== modified file 'bzrlib/tests/blackbox/test_merge_directive.py'
--- bzrlib/tests/blackbox/test_merge_directive.py	2007-03-12 03:48:18 +0000
+++ bzrlib/tests/blackbox/test_merge_directive.py	2007-03-14 14:54:34 +0000
@@ -46,6 +46,7 @@
         self.build_tree_contents([('tree1/file', 'a\nb\nc\nd\ne\n')])
         tree1.commit('bar')
         os.chdir('tree1')
+        return tree1, tree2
 
     def test_merge_directive(self):
         self.prepare_merge_directive()
@@ -97,8 +98,7 @@
             gpg.GPGStrategy = old_strategy
         self.assertContainsRe(md_text, '^-----BEGIN PSEUDO-SIGNED CONTENT')
 
-    def test_mail(self):
-        self.prepare_merge_directive()
+    def run_bzr_fakemail(self, *args, **kwargs):
         sendmail_calls = []
         def sendmail(self, from_, to, message):
             sendmail_calls.append((self, from_, to, message))
@@ -110,12 +110,18 @@
         old_connect = smtplib.SMTP.connect
         smtplib.SMTP.connect = connect
         try:
-            md_text = self.run_bzr('merge-directive', '--mail-to',
-                                   'pqm@example.com', '--plain', '../tree2',
-                                   '.')[0]
+            result = self.run_bzr(*args, **kwargs)
         finally:
             smtplib.SMTP.sendmail = old_sendmail
             smtplib.SMTP.connect = old_connect
+        return result + (connect_calls, sendmail_calls)
+
+    def test_mail_default(self):
+        tree1, tree2 = self.prepare_merge_directive()
+        md_text, errr, connect_calls, sendmail_calls =\
+            self.run_bzr_fakemail('merge-directive', '--mail-to',
+                                  'pqm@example.com', '--plain', '../tree2',
+                                  '.')
         self.assertEqual('', md_text)
         self.assertEqual(1, len(connect_calls))
         call = connect_calls[0]
@@ -125,3 +131,13 @@
         self.assertEqual(('J. Random Hacker <jrandom@example.com>',
                           'pqm@example.com'), call[1:3])
         self.assertContainsRe(call[3], EMAIL1)
+
+    def test_mail_uses_config(self):
+        tree1, tree2 = self.prepare_merge_directive()
+        tree1.branch.get_config().set_user_option('smtp_server', 'bogushost')
+        md_text, errr, connect_calls, sendmail_calls =\
+            self.run_bzr_fakemail('merge-directive', '--mail-to',
+                                  'pqm@example.com', '--plain', '../tree2',
+                                  '.')
+        call = connect_calls[0]
+        self.assertEqual(('bogushost', 0), call[1:3])

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- bzrlib/tests/test_merge_directive.py	2007-03-11 16:16:00 +0000
+++ bzrlib/tests/test_merge_directive.py	2007-03-13 16:59:44 +0000
@@ -131,6 +131,7 @@
             patch='booga', patch_type='diff')
         md2 = merge_directive.MergeDirective.from_lines(md.to_lines())
         self.assertEqual('example:', md2.revision_id)
+        self.assertIsInstance(md2.revision_id, str)
         self.assertEqual('sha', md2.testament_sha1)
         self.assertEqual('http://example.com', md2.target_branch)
         self.assertEqual('http://example.org', md2.source_branch)
@@ -147,6 +148,10 @@
         self.assertContainsRe(md3.to_lines()[0],
             '^# Bazaar merge directive format ')
         self.assertEqual("Hi mom!", md3.message)
+        md3.patch_type = None
+        md3.patch = None
+        md4 = merge_directive.MergeDirective.from_lines(md3.to_lines())
+        self.assertIs(None, md4.patch_type)
 
 
 EMAIL1 = """To: pqm@example.com

